pub fn parse_derive_position_to_report(
position: &DerivePosition,
account_id: AccountId,
ts_init: UnixNanos,
) -> Result<PositionStatusReport>Expand description
Builds a [PositionStatusReport] from a Derive position record.
Trailing zero padding is removed without changing the value.
Errors
Returns an error when the position amount cannot be converted to a
Nautilus Quantity.